@@ -19,11 +19,15 @@ class Tag(models.Model):
 
 
 class Blog(models.Model):
+    class Meta:
+        ordering = ['-created_at']
+
     title = models.CharField(max_length=225)
     content = models.TextField()
     author = models.ForeignKey(UserModel, on_delete=models.CASCADE)
     category = models.ForeignKey(Category, on_delete=models.CASCADE)
     tags = models.ManyToManyField(Tag)
+    created_at = models.DateTimeField(auto_now_add=True)
 
     def __str__(self):
         return self.title
